@@ -1,5 +1,6 @@
 import os
 
+import six
 import bottle
 from jinja2 import Environment, PackageLoader
 from bottle_debugtoolbar.toolbar import DebugToolbar
@@ -57,7 +58,7 @@ class DebugToolbarPlugin(object):
         self.jinja_env.filters['printable'] = _printable
 
         self.app.route(path='/_debug_toolbar/static/<filename:path>',
-                       name='_debug_toolbar.static', 
+                       name='_debug_toolbar.static',
                        callback=self.send_static_file)
 
     def apply(self, callback, route):
@@ -100,7 +101,7 @@ class DebugToolbarPlugin(object):
     def process_request(self, view_func, view_kwargs):
         if not self._show_toolbar():
             return
-        
+
         self.debug_toolbar = DebugToolbar(bottle.request, self.jinja_env)
 
         for panel in self.debug_toolbar.panels:
@@ -132,7 +133,7 @@ class DebugToolbarPlugin(object):
         # toolbar to the returned html response.
         if (bottle.response.status_code == 200
             and bottle.response.headers['content-type'].startswith('text/html')
-            and isinstance(content, basestring)):
+            and isinstance(content, six.string_types)):
             for panel in self.debug_toolbar.panels:
                 panel.process_response(bottle.request, content)
 
