@@ -1,19 +1,27 @@
+import six
+
+
+if six.PY3:
+    nrange = range
+else:
+    nrange = xrange
+
 
 #: list of characters that are always safe in URLs.
 _always_safe = ('ABCDEFGHIJKLMNOPQRSTUVWXYZ'
                 'abcdefghijklmnopqrstuvwxyz'
                 '0123456789_.-')
 _safe_map = dict((c, c) for c in _always_safe)
-for i in xrange(0x80):
+for i in nrange(0x80):
     c = chr(i)
     if c not in _safe_map:
         _safe_map[c] = '%%%02X' % i
-_safe_map.update((chr(i), '%%%02X' % i) for i in xrange(0x80, 0x100))
+_safe_map.update((chr(i), '%%%02X' % i) for i in nrange(0x80, 0x100))
 _safemaps = {}
 
 
 def _quote(s, safe='/', _join=''.join):
-    assert isinstance(s, str), 'quote only works on bytes'
+    assert isinstance(s, six.string_types), 'quote only works on bytes'
     if not s or not s.rstrip(_always_safe + safe):
         return s
     try:
@@ -22,7 +30,7 @@ def _quote(s, safe='/', _join=''.join):
         safe_map = _safe_map.copy()
         safe_map.update([(c, c) for c in safe])
         _safemaps[safe] = quoter = safe_map.__getitem__
-    return _join(map(quoter, s))
+    return _join(list(map(quoter, s)))
 
 
 def _quote_plus(s, safe=''):
@@ -39,8 +47,8 @@ def url_quote_plus(s, charset='utf-8', safe=''):
     :param charset: the charset to be used.
     :param safe: an optional sequence of safe characters.
     """
-    if isinstance(s, unicode):
+    if isinstance(s, six.text_type):
         s = s.encode(charset)
-    elif not isinstance(s, str):
+    elif not isinstance(s, six.string_types):
         s = str(s)
     return _quote_plus(s, safe=safe)
